package ru.ulstu.extractor.assessment.controller;

import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestParam;
import ru.ulstu.extractor.assessment.model.FilterBranchForm;
import ru.ulstu.extractor.branch.service.BranchService;
import ru.ulstu.extractor.rule.service.FuzzyInferenceService;
import springfox.documentation.annotations.ApiIgnore;

import java.util.Optional;

import static ru.ulstu.extractor.core.Route.ASSESSMENTS;

@Controller
@ApiIgnore
public class AssessmentController {
    private final FuzzyInferenceService fuzzyInferenceService;
    private final BranchService branchService;

    public AssessmentController(FuzzyInferenceService fuzzyInferenceService,
                                BranchService branchService) {
        this.fuzzyInferenceService = fuzzyInferenceService;
        this.branchService = branchService;
    }

    @GetMapping(ASSESSMENTS)
    public String getAssessments(Model model, @RequestParam Optional<Integer> branchId) {
        model.addAttribute("branches", branchService.findAll());
        if (branchId.isPresent()) {
            model.addAttribute("assessments", fuzzyInferenceService.getAssessments(branchId.get()));
            model.addAttribute("filterBranchForm", new FilterBranchForm(branchId.get()));
        } else {
            model.addAttribute("filterBranchForm", new FilterBranchForm());
        }
        return ASSESSMENTS;
    }
}
